Changelog
=========

0.1 (2012-04-24)
^^^^^^^^^^^^^^^^
* Initial release


0.2 (2013-01-27)
^^^^^^^^^^^^^^^^
* Renamed the tool from ``django-make-future-url.py`` to  ``future_url``
* Removed ``--dry-run`` option, to make actual changes use ``--write``
* Added python 3 support (Roman Gladkov)
* Internal refactoring
* Added tests